@@ -92,8 +92,9 @@ class TokenCheck(Token):
         self.token = kwargs['token']
         self.key = kwargs['key']
         try:
+            check = self.check_token(**kwargs)
             result = self.decode_string()
-            result["Check_token"] = self.check_token(**kwargs)
+            result["Check_token"] = check
             return result
         except:
             return "Token can broken"
